#!/usr/bin/env python3
# coding=UTF-8
#
# Copyright 2022. quinn.7@foxmail.com All rights reserved.
# Author :: cat7
# Email  :: quinn.7@foxmail.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, 
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# =============================================================================
"""
[ 帮助 ]

"""

import re
import subprocess

from rains import __version__


def function_update():
  dos_result = subprocess.Popen(['pip', 'install', 'rains=='], stderr=subprocess.PIPE)
  _out, err = dos_result.communicate()
  newest_version: str = re.findall(r'from versions: (.*)\)', str(err))[0].split(',')[-1].strip()

  message: str
  if newest_version > __version__:
    message = f'发现最新版本: { newest_version }, 正在执行更新程序...'
    print(re.sub('&message&', message, _MESSAGE))
    
    dos_result = subprocess.Popen(['pip', 'install', 'rains=='], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
    out, err = dos_result.communicate()
    if not err:
      print(out)
    else:
      print(err)

  else:
    message = '暂无更新...'
    print(re.sub('&message&', message, _MESSAGE))


_MESSAGE = \
"""
--------------------------------------
 更新
--------------------------------------

 &message&

--------------------------------------
"""



#!/usr/bin/env python3
# coding=UTF-8

from rains.kit.web.web_task import WebTask
from rains.kit.web.web_plant import BY


class Task(WebTask):
    """
    [ Task ]

    """

    # ------------------------------
    def set_task_init(self):
        """
        [ 设置任务初始化 ]

        * 该接口将在 [ 任务 ] 开始时执行, 全程只会执行一次.

        """

        # 在这里实例化元素对象

        # 百度搜索框元素定位
        self.search_input = self.plant.element(
            page='百度',
            name='搜索框',
            by_key=BY.ID,
            by_value='kw'
        )

        # 百度百度一下元素定位
        self.ok_button = self.plant.element(
            page='百度',
            name='百度一下',
            by_key=BY.ID,
            by_value='su'
        )

    # ------------------------------
    def set_task_quit(self):
        """
        [ 设置任务注销 ]

        * 该接口将在 [ 任务 ] 结束后执行, 全程只会执行一次.

        """
        ...

    # ------------------------------
    def set_case_init(self):
        """
        [ 设置用例初始化 ]

        * 该接口将在每次 [ 用例 ] 开始时执行.

        """
        ...

    # ------------------------------
    def set_case_quit(self):
        """
        [ 设置用例注销 ]

        * 该接口将在每次 [ 用例 ] 结束后执行.

        """
        ...

    # ------------------------------
    def case_1(self):
        """
        [ 用例1 ]

        """

        # 页面访问URL
        self.plant.view.page.goto('http://www.baidu.com/')

        # 百度搜索框输入内容
        self.search_input.input.send('rains')

        # 点击百度一下
        self.ok_button.mouse.tap()



#!/usr/bin/env python3
# coding=UTF-8
#
# Copyright 2022. quinn.7@foxmail.com All rights reserved.
# Author :: cat7
# Email  :: quinn.7@foxmail.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, 
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# =============================================================================
"""
[ 命令行工具实现 ]

"""
import sys


def main():
    command: str = 'order'
    if len(sys.argv) > 1:
        command: str = sys.argv[1]

    # ------------------------------
    if command in ['order', '-order', '-o']:
        from rains.external.order import function_order
        function_order()

    # ------------------------------
    elif command in ['init', '-init', '-i']:
        from rains.external.init_engineering import function_init_engineering
        function_init_engineering()

    # ------------------------------
    elif command in ['make', '-make', '-m']:
        from rains.external.create_project import function_create_project
        function_create_project()

    # ------------------------------
    elif command in ['task', '-task', '-t']:
        from rains.external.create_task import function_create_task
        function_create_task()

    # ------------------------------
    elif command in ['run', '-run', '-r']:
        from rains.external.run_task import function_run_task
        function_run_task()

    # ------------------------------
    elif command in ['server', '-server', '-s']:
        from rains.external.run_server import function_run_server
        function_run_server()

    # ------------------------------
    elif command in ['help', '-help', '-h']:
        from rains.external.help import function_help
        function_help()

    # ------------------------------
    elif command in ['version', '-version', '-v']:
        from rains.external.version import function_version
        function_version()

    # ------------------------------
    elif command in ['update', '-update', '-u']:
        from rains.external.update import function_update
        function_update()

    else:
        print('error:: rains不存在这样的指令!')



#!/usr/bin/env python3
# coding=UTF-8
#
# Copyright 2022. quinn.7@foxmail.com All rights reserved.
# Author :: cat7
# Email  :: quinn.7@foxmail.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, 
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# =============================================================================
"""
[ rains 全栈自动化测试框架 ]

"""

__version__ = '0.3.8'

__name__ = 'rains'
__author__ = 'cat7'
__email__ = 'quinn.7@foxmail.com'
__description__ = '这是一个开箱即用、稳定且高效的工程化全栈自动化测试框架。'
__url__ = 'https://gitee.com/catcat7/rains'



#!/usr/bin/env python3
# coding=UTF-8

import setuptools

from rains import __name__
from rains import __version__
from rains import __author__
from rains import __email__
from rains import __description__
from rains import __url__


with open('README.md', 'r', encoding='utf-8') as fh:
    long_description = fh.read()


setuptools.setup(

    name=__name__, 
    version=__version__, 
    author=__author__, 
    author_email=__email__, 
    description=__description__, 
    long_description=long_description, 
    long_description_content_type='text/markdown', 
    url=__url__, 
    keywords=['rains', 'test', 'web', 'api'],
    packages=setuptools.find_packages(), 

    install_requires=[
        'Selenium == 3.14.1', 
        'requests', 
        'flask', 
    ], 

    classifiers=[
        'Programming Language :: Python :: 3', 
    ],

    # 打包文件
    data_files=[],

    # 安装执行脚本
    scripts=[],

    # 命令行工具
    entry_points={
        'console_scripts':[
            'rains = rains.console_rains:main',
        ],
    },
)
